@@ -1,5 +1,4 @@
 """Tools for the Advent of Code."""
-
-from .aoc import Puzzle
+from .puzzle import Puzzle
 
 __all__ = ["Puzzle"]
